Download occurrence records for multiple taxa
Source:R/bdcr_occurrences_batch.R
bdcr_occurrences_batch.RdDownload occurrence records for multiple taxa
Value
Named list of tibbles, one per taxon. If the service is unavailable for a given taxon, the corresponding element will be an empty `tibble`.
Examples
if (FALSE) { # \dontrun{
spp <- c("Tapirus bairdii", "Panthera onca")
bdcr_occurrences_batch(spp, rows = 50)
} # }